@@ -314,9 +314,7 @@ GVContactsTable::onLoginResponse(bool success, const QByteArray &response,
 
     strGoogleAuth.clear ();
     do { // Begin cleanup block (not a loop)
-        if (!success) {
-            break;
-        }
+        if (!success) break;
 
         QUrl urlMoved = hasMoved(reply);
         if (!urlMoved.isEmpty ()) {
@@ -372,6 +370,11 @@ GVContactsTable::onLoginResponse(bool success, const QByteArray &response,
     if (token) {
         delete token;
     }
+
+    if (!bLoggedIn) {
+        CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
+        dbMain.clearContactsPass ();
+    }
 }//GVContactsTable::onLoginResponse
 
 #ifndef NO_CONTACTS_CAPTCHA
@@ -625,7 +628,7 @@ void
 GVContactsTable::onSearchQueryChanged (const QString &query)
 {
     if (NULL != modelSearchContacts) {
-        modelSearchContacts->refresh (query);
+        modelSearchContacts->refresh(query);
     }
 }//GVContactsTable::onSearchQuerychanged
 
