@@ -27,7 +27,7 @@ Contact: yuvraaj@gmail.com
 
 OsDependent::OsDependent(QObject *parent) : QObject(parent)
 {
-#if QTM_VERSION >= 0x010200
+#if SYSTEMDISPLAYINFO
     displayInfo = NULL;
 #endif
 #if HAS_FEEDBACK
@@ -47,7 +47,7 @@ OsDependent::init ()
 #endif
 
     bool rv; Q_UNUSED(rv);
-#if QTM_VERSION >= 0x010200
+#if SYSTEMDISPLAYINFO
     displayInfo = new QSystemDisplayInfo(this);
 
     rv =
@@ -82,6 +82,38 @@ OsDependent::isN900 ()
 #endif
 }//OsDependent::isN900
 
+bool
+OsDependent::isSymbian()
+{
+#if defined(Q_OS_SYMBIAN)
+    return true;
+#else
+    return false;
+#endif
+}//OsDependent::isSymbian
+
+bool
+OsDependent::isSymbian1()
+{
+    bool rv = false;
+#if defined(Q_OS_SYMBIAN)
+    QSysInfo::SymbianVersion symVer = QSysInfo::symbianVersion();
+    rv = (symVer == QSysInfo::SV_SF_1);
+#endif
+    return (rv);
+}//OsDependent::isSymbian1
+
+bool
+OsDependent::isSymbian3()
+{
+    bool rv = false;
+#if defined(Q_OS_SYMBIAN)
+    QSysInfo::SymbianVersion symVer = QSysInfo::symbianVersion();
+    rv = (symVer == QSysInfo::SV_SF_3);
+#endif
+    return (rv);
+}//OsDependent::isSymbian3
+
 void
 OsDependent::initDialServer (QObject *receiver, const char *method)
 {
@@ -212,7 +244,7 @@ OsDependent::getStartingSize ()
     return rect;
 }//OsDependent::getStartingSize
 
-#if QTM_VERSION >= 0x010200
+#if SYSTEMDISPLAYINFO
 void
 OsDependent::onOrientationChanged(QSystemDisplayInfo::DisplayOrientation o)
 {
@@ -266,7 +298,12 @@ OsDependent::getOrientation(void)
 {
     OsIndependentOrientation rv = OIO_Unknown;
 
-#if QTM_VERSION >= 0x010200
+#if DESKTOP_OS || defined(Q_OS_SYMBIAN) || defined(MEEGO_HARMATTAN)
+
+    rv = OIO_Portrait;
+
+#elif SYSTEMDISPLAYINFO
+
     switch (displayInfo->orientation(0)) {
     case QSystemDisplayInfo::Landscape:
         rv = OIO_Landscape;
@@ -284,17 +321,16 @@ OsDependent::getOrientation(void)
     default:
         break;
     }
+
 #else
+
     QRect screenGeometry = QApplication::desktop()->screenGeometry();
     if (screenGeometry.width() > screenGeometry.height()) {
         rv = OIO_Landscape;
     } else {
         rv = OIO_Portrait;
     }
-#endif
 
-#if DESKTOP_OS
-    rv = OIO_Portrait;
 #endif
 
     return (rv);
@@ -323,11 +359,15 @@ OsDependent::getAppDirectory ()
 QString
 OsDependent::getMainQML ()
 {
-    return "qrc:/"
 #if defined(MEEGO_HARMATTAN)
-    "H"
+    return "qrc:/HMain.qml";
+#else
+    if (isSymbian3 ()) {
+        return "qrc:/S3Main.qml";
+    } else {
+        return "qrc:/Main.qml";
+    }
 #endif
-    "Main.qml";
 }//OsDependent::getMainQML
 
 void
